@@ -3,7 +3,7 @@ package main
 import (
 	"fmt"
 
-	"example"
+	"swigtests/example"
 )
 
 func main() {
