@@ -1,11 +1,10 @@
 package main
 
-import . "./template_typedef_cplx3"
+import . "swigtests/template_typedef_cplx3"
 
 func main() {
 	// this is OK
 
-
 	s := NewSin()
 	s.Get_base_value()
 	s.Get_value()
