@@ -23,10 +23,10 @@ public class cpp11_constexpr_runme {
     check(cpp11_constexpr.CCC(), 30);
     check(cpp11_constexpr.DDD(), 40);
 
-    ConstExpressions ce = new ConstExpressions();
-    check(ce.JJJ, 100);
-    check(ce.KKK, 200);
-    check(ce.LLL, 300);
+    ConstExpressions ce = new ConstExpressions(0);
+    check(ConstExpressions.JJJ, 100);
+    check(ConstExpressions.KKK, 200);
+    check(ConstExpressions.LLL, 300);
     check(ce.MMM(), 400);
     check(ce.NNN(), 500);
   }
