@@ -13,6 +13,8 @@ public class li_boost_shared_ptr_runme {
   // Debugging flag
   public final static boolean debug = false;
 
+  // Suppress warning about System.runFinalization() call.
+  @SuppressWarnings({"deprecation", "removal"})
   private static void WaitForGC()
   {
     System.gc();
@@ -23,6 +25,8 @@ public class li_boost_shared_ptr_runme {
     }
   }
 
+  // Suppress warning about System.runFinalization() call.
+  @SuppressWarnings({"deprecation", "removal"})
   public static void main(String argv[]) 
   {
     if (debug)
@@ -605,7 +609,7 @@ public class li_boost_shared_ptr_runme {
       throw new RuntimeException("verify value failed. Expected: " + expected + " Got: " + got);
   }
   private void verifyCount(int expected, Klass k) {
-    int got = (int)li_boost_shared_ptr.use_count(k); 
+    int got = li_boost_shared_ptr.use_count(k);
     if (expected != got)
       throw new RuntimeException("verify use_count failed. Expected: " + expected + " Got: " + got);
   }
