@@ -2,13 +2,18 @@ var char_binary = require("char_binary");
 
 var t = new char_binary.Test();
 if (t.strlen('hile') != 4) {
-  print(t.strlen('hile'));
+  throw("bad multi-arg typemap 1");
+}
+if (t.ustrlen('hile') != 4) {
   throw("bad multi-arg typemap 1");
 }
 
 if (t.strlen('hil\0') != 4) {
   throw("bad multi-arg typemap 2");
 }
+if (t.ustrlen('hil\0') != 4) {
+  throw("bad multi-arg typemap 2");
+}
 
 /*
  *  creating a raw char*
@@ -24,10 +29,12 @@ char_binary.pchar_setitem(pc, 4, 0);
 if (t.strlen(pc) != 4) {
   throw("bad multi-arg typemap (3)");
 }
+if (t.ustrlen(pc) != 4) {
+  throw("bad multi-arg typemap (3)");
+}
 
 char_binary.var_pchar = pc;
 if (char_binary.var_pchar != "hola") {
-  print(char_binary.var_pchar);
   throw("bad pointer case (1)");
 }
 
