@@ -11,4 +11,7 @@ let _ =
   assert (_testJim '(name) as string = "multiname num");
   let arg = new_PairIntBool '(10, false) in
   assert (_testJohn '(arg) as int = 123);
+  assert (_makeStringInt '("stringint", 999) as string = "stringint");
+  assert (_provideStringInt '(999) as string = "1000");
+  assert (_shortFunction '(1, 1) as int = (200*2 + 200*3));
 ;;
