@@ -2,6 +2,6 @@ abstract_access
 
 d = abstract_access.D();
 if (d.do_x() != 1)
-   error
+   error("failed");
 endif
 
