@@ -10,7 +10,7 @@ f11 = Foo1(f1);
 
 
 if (f1.x != f11.x)
-    error
+    error("failed");
 endif
 
 
@@ -23,7 +23,7 @@ catch
 end_try_catch
 
 if (!good)
-    error
+    error("failed");
 endif
 
 
@@ -31,7 +31,7 @@ bi = Bari(5);
 bc = Bari(bi);
 
 if (bi.x != bc.x)
-    error
+    error("failed");
 endif
     
 
@@ -44,6 +44,6 @@ catch
 end_try_catch
 
 if (!good)
-    error
+    error("failed");
 endif
 
