@@ -8,6 +8,6 @@ o << a << " " << 2345 << " " << 1.435;
 
 
 if (o.str() !=  "A class 2345 1.435")
-  error
+  error("failed");
 endif
 
