@@ -4,7 +4,7 @@ require "tests.php";
 // New functions
 check::functions(array('archiving_on', 'archiving_onw', 'doublevalue1','doublevalue2','seek','seek2','seek3','seek4','seek5','seek6','seek7','seek8','seek9','seeka','seekb','anonymous','booltest','casts1','casts2','chartest1','chartest2','chartest3','chartest4','chartest5','chartest6','dummy','afunction','reftest1','reftest2','chops','exceptionspec','constructorcall','cfunc1','cfunc2','cfunc3','nasty_default_expression','slightly_off_square','subscripted_default_arg'));
 // New classes
-check::classes(array('TrickyInPython','default_args','EnumClass','DerivedEnumClass','Tree','Foo','MyClass1','MyClass2','Except','Statics','Tricky','Klass','ConstMethods','Pointf','CDA'));
+check::classes(array('TrickyInPython','default_args','EnumClass','DerivedEnumClass','Tree','Foo','MyClass1','MyClass2','Except','Statics','Tricky','Klass','ConstMethods','Pointf','CDA','Q'));
 // New vars
 check::globals(array('CONST_NUM'));
 
@@ -114,6 +114,15 @@ check::equal(slightly_off_square(10), 102, "slightly_off_square(10)");
 
 check::equal(slightly_off_square(), 291, "slightly_off_square()");
 
+check::equal(Q::slightly_off_square_static(10), 102, "Q::slightly_off_square_static(10)");
+
+check::equal(Q::slightly_off_square_static(), 291, "Q::slightly_off_square_static()");
+
+$q = new Q();
+check::equal($q->slightly_off_square(10), 102, "Q::slightly_off_square(10)");
+
+check::equal($q->slightly_off_square(), 291, "Q::slightly_off_square()");
+
 check::equal(chartest1(), "x", "chartest1()");
 
 check::equal(chartest2(), "\0", "chartest2()");
