@@ -1,15 +1,12 @@
 <?php
 
 require "tests.php";
-require "director_basic.php";
 
-/* Removed until runtime error is fixed, see https://github.com/swig/swig/issues/164
 // No new functions
-check::functions(array(foo_ping,foo_pong,foo_get_self,a_f,a_rg,a1_ff,myclass_method,myclass_vmethod,myclass_pmethod,myclass_cmethod,myclass_get_self,myclass_call_pmethod,myclasst_i_method));
-// No new classes
-check::classes(array(Foo,A,A1,Bar,MyClass,MyClassT_i));
-// now new vars
-check::globals(array(bar_x));
+check::functions(array());
+check::classes(array('Foo','A','A1','Bar','MyClass','MyClassT_i','ConstPtrClass'));
+// No new vars
+check::globals(array());
 
 class PhpFoo extends Foo {
   function ping() {
@@ -54,7 +51,5 @@ $cc->method($b);
 
 check::equal($bc->x, 34, "bc failed");
 check::equal($bd->x, 16, "bd failed");
-*/
 
 check::done();
-?>
