@@ -1,10 +1,9 @@
-<?
+<?php
 require "tests.php";
-require "exception_order.php";
 
-check::functions(array('a_foo','a_bar','a_foobar','a_barfoo','is_python_builtin'));
+check::functions(array());
 check::classes(array('A','E1','E2','E3','exception_order','ET_i','ET_d'));
-check::globals(array('efoovar','foovar','cfoovar','a_sfoovar','a_foovar','a_efoovar'));
+check::globals(array('efoovar','foovar','cfoovar'));
 
 $a = new A();
 try {
@@ -36,4 +35,5 @@ try {
 } catch (Exception $e) {
     check::equal($e->getMessage(), 'C++ E2 * exception thrown', '');
 }
-?>
+
+check::done();
