@@ -1,10 +1,6 @@
 import director_abstract
 
 
-def is_new_style_class(cls):
-    return hasattr(cls, "__class__")
-
-
 class MyFoo(director_abstract.Foo):
 
     def __init__(self):
@@ -17,10 +13,10 @@ class MyFoo(director_abstract.Foo):
 a = MyFoo()
 
 if a.ping() != "MyFoo::ping()":
-    raise RuntimeError, a.ping()
+    raise RuntimeError(a.ping())
 
 if a.pong() != "Foo::pong();MyFoo::ping()":
-    raise RuntimeError, a.pong()
+    raise RuntimeError(a.pong())
 
 
 class MyExample1(director_abstract.Example1):
@@ -41,23 +37,15 @@ class MyExample3(director_abstract.Example3_i):
         return b
 
 me1 = MyExample1()
-if director_abstract.Example1_get_color(me1, 1, 2, 3) != 1:
+if director_abstract.Example1.get_color(me1, 1, 2, 3) != 1:
     raise RuntimeError
 
-if is_new_style_class(MyExample2):
-    MyExample2_static = MyExample2
-else:
-    MyExample2_static = MyExample2(0, 0)
 me2 = MyExample2(1, 2)
-if MyExample2_static.get_color(me2, 1, 2, 3) != 2:
+if MyExample2.get_color(me2, 1, 2, 3) != 2:
     raise RuntimeError
 
-if is_new_style_class(MyExample3):
-    MyExample3_static = MyExample3
-else:
-    MyExample3_static = MyExample3()
 me3 = MyExample3()
-if MyExample3_static.get_color(me3, 1, 2, 3) != 3:
+if MyExample3.get_color(me3, 1, 2, 3) != 3:
     raise RuntimeError
 
 error = 1
