@@ -14,7 +14,6 @@ d = Derived()
 d.run()
 
 if d.val >= 0:
-    print d.val
-    raise RuntimeError
+    raise RuntimeError("d.val: {}".format(d.val))
 
 d.stop()
