@@ -1,10 +1,9 @@
 
 from li_cdata import *
 
-s = "ABC abc"
+s = "ABC\x00abc"
 m = malloc(256)
 memmove(m, s)
 ss = cdata(m, 7)
-if ss != "ABC abc":
-  raise "failed"
-
+if ss != "ABC\x00abc":
+    raise "failed"
