@@ -2,6 +2,10 @@ from li_cpointer_cpp import *
 
 
 p = new_intp()
+
+if intp_value(p) != 0:
+    raise RuntimeError("not initialized")
+
 intp_assign(p, 3)
 
 if intp_value(p) != 3:
