@@ -7,25 +7,23 @@ if count("ab\0ab\0ab\0", 0) != 3:
 if test1() != "Hello World":
     raise RuntimeError
 
-if test2() != " !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_":
+if test2() != " !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_":
     raise RuntimeError
 
 if test3("hello") != "hello-suffix":
-    print test3("hello")
-    raise RuntimeError
+    raise RuntimeError("test3(\"hello\")")
 
 if test4("hello") != "hello-suffix":
-    print test4("hello")
+    raise RuntimeError("test4(\"hello\")")
+
+if test5(4) != "xxxx":
     raise RuntimeError
 
-if test5(4) != 'xxxx':
-    raise RuntimeError
-
-if test6(10) != 'xxxxx':
+if test6(10) != "xxxxx":
     raise RuntimeError
 
 if test7() != "Hello world!":
     raise RuntimeError
 
-if test8() != " !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_":
+if test8() != " !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_":
     raise RuntimeError
