@@ -1,7 +1,6 @@
 from li_std_stream import *
 
 
-
 a = A()
 
 o = ostringstream()
@@ -9,6 +8,5 @@ o = ostringstream()
 o << a << " " << 2345 << " " << 1.435
 
 
-if o.str() !=  "A class 2345 1.435":
-  print "\"%s\"" % (o.str(),)
-  raise RuntimeError
+if o.str() != "A class 2345 1.435":
+    raise RuntimeError("str failed: \"%s\"".format(o.str()))
