@@ -4,5 +4,4 @@ from virtual_derivation import *
 #
 b = B(3)
 if b.get_a() != b.get_b():
-  raise RuntimeError, "something is really wrong"
-
+    raise RuntimeError("something is really wrong")
