@@ -27,17 +27,27 @@ namespace Space {
     void templateXYZ(XYZ<T> i) {}
     operator T() { return m_t; }
     operator NotXYZ<T>() const { return m_notxyz; }
-    operator XYZ<T>() const { XYZ<T> xyz = XYZ<T>(); return xyz; }
   };
 }
 
+#if defined(SWIG)
+%exception Space::ABC::operator ABC %{
+#if defined(__clang__)
+  // Workaround for: warning: conversion function converting 'Space::ABC' to itself will never be used
+  result = *arg1;
+#else
+  $action
+#endif
+%}
+#endif
+
 namespace Space {
 // non-templated class using itself in method and operator
 class ABC {
   public:
     void method(ABC a) const {}
     void method(Klass k) const {}
-    operator ABC() const { ABC a; return a; }
+    operator ABC*() const { return new ABC(); }
     operator Klass() const { Klass k; return k; }
 };
 }
