@@ -1,3 +1,14 @@
+#!/usr/bin/env ruby
+#
+# Put description here
+#
+# 
+# 
+# 
+#
+
+require 'swig_assert'
+
 require 'abstract_inherit_ok'
 
 include Abstract_inherit_ok
@@ -17,7 +28,7 @@ rescue TypeError
   # TypeError: allocator undefined for Abstract_inherit_ok::Foo
 	exceptionRaised = true
 ensure
-  raise RuntimeError unless exceptionRaised
+  swig_assert( "exceptionRaised", binding )
 end
 
 #
@@ -32,6 +43,6 @@ begin
 rescue NameError
   exceptionRaised = true
 ensure
-  raise RuntimeError if exceptionRaised
+  swig_assert( "!exceptionRaised", binding )
 end
 
