@@ -25,7 +25,7 @@ void DohDelete(DOH *obj) {
   if (!obj)
     return;
   if (!DohCheck(b)) {
-    fputs("Fatal internal error: Attempt to delete a non-DOH object.\n", stderr);
+    fputs("Internal error: Attempt to delete a non-DOH object.\n", stderr);
     Exit(EXIT_FAILURE);
   }
   if (b->flag_intern)
@@ -55,7 +55,7 @@ DOH *DohCopy(const DOH *obj) {
   if (!obj)
     return 0;
   if (!DohCheck(b)) {
-    fputs("Fatal internal error: Attempt to copy a non-DOH object.\n", stderr);
+    fputs("Internal error: Attempt to copy a non-DOH object.\n", stderr);
     Exit(EXIT_FAILURE);
   }
   objinfo = b->type;
@@ -207,7 +207,8 @@ int DohCmp(const DOH *obj1, const DOH *obj2) {
   b2info = b2->type;
   if ((b1info == b2info) && (b1info->doh_cmp))
     return (b1info->doh_cmp) (b1, b2);
-  return 1;
+  /* finally compare pointers */
+  return b1 < b2 ? -1 : b1 == b2 ? 0 : 1;
 }
 
 /* -----------------------------------------------------------------------------
