@@ -360,9 +360,9 @@ List *Swig_overload_rank(Node *n, bool script_lang_wrapping) {
   return result;
 }
 
-// /* -----------------------------------------------------------------------------
-//  * print_typecheck()
-//  * ----------------------------------------------------------------------------- */
+/* -----------------------------------------------------------------------------
+ * print_typecheck()
+ * ----------------------------------------------------------------------------- */
 
 static bool print_typecheck(String *f, int j, Parm *pj, bool implicitconvtypecheckoff) {
   char tmp[256];
@@ -425,10 +425,11 @@ static String *ReplaceFormat(const_String_or_char_ptr fmt, int j) {
 /*
   Cast dispatch mechanism.
 */
-String *Swig_overload_dispatch_cast(Node *n, const_String_or_char_ptr fmt, int *maxargs) {
+String *Swig_overload_dispatch_cast(Node *n, const_String_or_char_ptr fmt, int *maxargs, bool *check_emitted) {
   int i, j;
 
-  *maxargs = 1;
+  *maxargs = 0;
+  *check_emitted = false;
 
   String *f = NewString("");
   String *sw = NewString("");
@@ -533,6 +534,7 @@ String *Swig_overload_dispatch_cast(Node *n, const_String_or_char_ptr fmt, int *
 	  }
 
 	  if (emitcheck) {
+	    *check_emitted = true;
 	    if (need_v) {
 	      Printf(f, "int _v = 0;\n");
 	      need_v = 0;
@@ -612,10 +614,11 @@ String *Swig_overload_dispatch_cast(Node *n, const_String_or_char_ptr fmt, int *
 /*
   Fast dispatch mechanism, provided by  Salvador Fandi~no Garc'ia (#930586).
 */
-static String *overload_dispatch_fast(Node *n, const_String_or_char_ptr fmt, int *maxargs, const_String_or_char_ptr fmt_fastdispatch) {
+static String *overload_dispatch_fast(Node *n, const_String_or_char_ptr fmt, int *maxargs, bool *check_emitted, const_String_or_char_ptr fmt_fastdispatch) {
   int i, j;
 
-  *maxargs = 1;
+  *maxargs = 0;
+  *check_emitted = false;
 
   String *f = NewString("");
 
@@ -713,6 +716,7 @@ static String *overload_dispatch_fast(Node *n, const_String_or_char_ptr fmt, int
 	  }
 
 	  if (emitcheck) {
+	    *check_emitted = true;
 	    if (need_v) {
 	      Printf(f, "int _v = 0;\n");
 	      need_v = 0;
@@ -775,15 +779,16 @@ static String *overload_dispatch_fast(Node *n, const_String_or_char_ptr fmt, int
   return f;
 }
 
-String *Swig_overload_dispatch(Node *n, const_String_or_char_ptr fmt, int *maxargs, const_String_or_char_ptr fmt_fastdispatch) {
+String *Swig_overload_dispatch(Node *n, const_String_or_char_ptr fmt, int *maxargs, bool *check_emitted, const_String_or_char_ptr fmt_fastdispatch) {
 
   if (fast_dispatch_mode || GetFlag(n, "feature:fastdispatch")) {
-    return overload_dispatch_fast(n, fmt, maxargs, fmt_fastdispatch);
+    return overload_dispatch_fast(n, fmt, maxargs, check_emitted, fmt_fastdispatch);
   }
 
   int i, j;
 
-  *maxargs = 1;
+  *maxargs = 0;
+  *check_emitted = false;
 
   String *f = NewString("");
 
@@ -824,6 +829,7 @@ String *Swig_overload_dispatch(Node *n, const_String_or_char_ptr fmt, int *maxar
 	pj = Getattr(pj, "tmap:in:next");
 	continue;
       }
+      *check_emitted = true;
       if (j >= num_required) {
 	String *lfmt = ReplaceFormat(fmt, num_arguments);
 	Printf(f, "if (%s <= %d) {\n", argc_template_string, j);
