@@ -19,10 +19,15 @@ extern Parm      *NewParmNode(SwigType *type, Node *from_node);
 extern Parm      *CopyParm(Parm *p);
 
 /* Parameter lists */
-extern ParmList  *CopyParmList(ParmList *);
-extern ParmList  *CopyParmListMax(ParmList *, int count);
-extern int        ParmList_len(ParmList *);
+extern ParmList  *CopyParmList(ParmList *p);
+extern ParmList  *CopyParmListMax(ParmList *p, int count);
+extern ParmList  *ParmList_join(ParmList *p, ParmList *p2);
+extern ParmList  *ParmList_replace_last(ParmList *p, ParmList *p2);
+extern Parm      *ParmList_nth_parm(ParmList *p, unsigned int n);
+extern Parm      *ParmList_variadic_parm(ParmList *p);
+extern Parm      *ParmList_add_parm(ParmList *p, Parm *newparm);
 extern int        ParmList_numrequired(ParmList *);
+extern int        ParmList_len(ParmList *);
 extern int        ParmList_has_defaultargs(ParmList *p);
 extern int        ParmList_has_varargs(ParmList *p);
 
